COMPMID-401: Implement FixedPointPosition conversion for NEON.

Adds support of changing the fixed point position of a tensor in
DepthConvert.

Change-Id: Ic3b50a4628fac7497a0217d92941c9d6f64d21cb
Reviewed-on: http://mpd-gerrit.cambridge.arm.com/80438
Reviewed-by: Anthony Barbier <anthony.barbier@arm.com>
Tested-by: Kaizen <jeremy.johnson+kaizengerrit@arm.com>
diff --git a/tests/validation/Reference.h b/tests/validation/Reference.h
index 3ad9814..a3ae3b6 100644
--- a/tests/validation/Reference.h
+++ b/tests/validation/Reference.h
@@ -168,16 +168,18 @@
     static RawTensor compute_reference_box3x3(const TensorShape &shape, BorderMode border_mode, uint8_t constant_border_value);
     /** Compute reference depth convert.
      *
      * @param[in] shape                Shape of the input and output tensors.
      * @param[in] dt_in                Data type of input tensor.
      * @param[in] dt_out               Data type of the output tensor.
      * @param[in] policy               Overflow policy of the operation.
      * @param[in] shift                Value for down/up conversions. Must be 0 <= shift < 8.
      * @param[in] fixed_point_position Fixed point position.
      *
      * @return Computed raw tensor.
      */
-    static RawTensor compute_reference_depth_convert(const TensorShape &shape, DataType dt_in, DataType dt_out, ConvertPolicy policy, uint32_t shift, uint32_t fixed_point_position);
+    static RawTensor compute_reference_depth_convert(const TensorShape &shape, DataType dt_in, DataType dt_out, ConvertPolicy policy,
+                                                     uint32_t shift, uint32_t fixed_point_position_in = 0, uint32_t fixed_point_position_out = 0);
     /** Compute reference gaussian3x3 filter.
      *
      * @param[in] shape                 Shape of the input and output tensors.
@@ -168,16 +168,18 @@
     /** Compute reference depth convert.
      *
-     * @param[in] shape                Shape of the input and output tensors.
-     * @param[in] dt_in                Data type of input tensor.
-     * @param[in] dt_out               Data type of the output tensor.
-     * @param[in] policy               Overflow policy of the operation.
-     * @param[in] shift                Value for down/up conversions. Must be 0 <= shift < 8.
-     * @param[in] fixed_point_position Fixed point position.
+     * @param[in] shape                    Shape of the input and output tensors.
+     * @param[in] dt_in                    Data type of input tensor.
+     * @param[in] dt_out                   Data type of the output tensor.
+     * @param[in] policy                   Overflow policy of the operation.
+     * @param[in] shift                    Value for down/up conversions. Must be 0 <= shift < 8.
+     * @param[in] fixed_point_position_in  (Optional) Fixed point position for the input tensor.
+     * @param[in] fixed_point_position_out (Optional) Fixed point position for the output tensor.
      *
      * @return Computed raw tensor.